larryi 02/02/08 12:23:48
Modified: src/share/org/apache/tomcat/modules/server
Ajp13Interceptor.java
Log:
Change the "authenticate" attribute to authenticateConnection since it
happens per connection instead of per request.
Revision Changes Path
1.20 +8 -8
jakarta-tomcat/src/share/org/apache/tomcat/modules/server/Ajp13Interceptor.java
Index: Ajp13Interceptor.java
===================================================================
RCS file:
/home/cvs/jakarta-tomcat/src/share/org/apache/tomcat/modules/server/Ajp13Interceptor.java,v
retrieving revision 1.19
retrieving revision 1.20
diff -u -r1.19 -r1.20
--- Ajp13Interceptor.java 8 Feb 2002 12:48:04 -0000 1.19
+++ Ajp13Interceptor.java 8 Feb 2002 20:23:48 -0000 1.20
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-tomcat/src/share/org/apache/tomcat/modules/server/Ajp13Interceptor.java,v
1.19 2002/02/08 12:48:04 larryi Exp $
- * $Revision: 1.19 $
- * $Date: 2002/02/08 12:48:04 $
+ * $Header:
/home/cvs/jakarta-tomcat/src/share/org/apache/tomcat/modules/server/Ajp13Interceptor.java,v
1.20 2002/02/08 20:23:48 larryi Exp $
+ * $Revision: 1.20 $
+ * $Date: 2002/02/08 20:23:48 $
*
* ====================================================================
*
@@ -88,7 +88,7 @@
private int decodedNote;
private String secret=null;
private File ajpidFile=null;
- private boolean authenticateRequests=false;
+ private boolean authenticateConnection=false;
public Ajp13Interceptor()
{
@@ -145,8 +145,8 @@
/** Specify if Ajp13 requests must be authenticated
*/
- public void setAuthenticateRequests( boolean b ) {
- authenticateRequests=b;
+ public void setAuthenticateConnection( boolean b ) {
+ authenticateConnection=b;
}
public void setDecodedUri( boolean b ) {
@@ -276,9 +276,9 @@
boolean moreRequests = true;
boolean authenticated = false;
// If we are not configured with a secret or we are
// not authenticating requests, assume
// we trust the remote party ( as we did before )
- if( secret == null || !authenticateRequests )
+ if( secret == null || !authenticateConnection )
authenticated=true;
while(moreRequests) {
@@ -276,9 +276,9 @@
boolean authenticated = false;
// If we are not configured with a secret or we are
- // not authenticating requests, assume
+ // not authenticating the connection, assume
// we trust the remote party ( as we did before )
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>